@@ -6,7 +6,7 @@
 #' the survival outcome from a Weibull model where the time
 #' to event depends on the random effects from the LMMs.
 #' It is an implementation of the simulation method used in
-#' Signorelli et al. (2020, in review)
+#' Signorelli et al. (2021, in review)
 #' 
 #' @param n sample size
 #' @param p number of longitudinal outcomes
@@ -29,7 +29,7 @@
 #' \itemize{
 #' \item a dataframe \code{long.data} with data on the longitudinal 
 #' predictors, comprehensive of a subject id (\code{id}),
-#' baseline age (\code{base.age}),time from baseline
+#' baseline age (\code{base.age}), time from baseline
 #' (\code{t.from.base}) and the longitudinal biomarkers;
 #' \item a dataframe \code{surv.data} with the survival data: 
 #' a subject id (\code{id}), baseline age (\code{baseline.age}),
@@ -75,8 +75,8 @@ simulate_prclmm_data = function(n = 100, p = 10, p.relev = 4,
               lambda = 0.2, nu = 2, seed = 1,
               base.age.range = c(3, 5),
               cens.range = c(0.5, 10), t.values = c(0, 0.5, 1, 2)) {
-  if (n <= 0) stop('n should be a positive integer')
-  if (p <= 0 | p.relev <=0) stop('p and p.relev should be a positive integer')
+  if (n < 1) stop('n should be a positive integer')
+  if (p < 1 | p.relev < 1) stop('p and p.relev should be a positive integer')
   if (p.relev > p) stop('p.relev should be <= p')
   if (lambda <=0 | nu <= 0 | n <=0) stop('lambda, nu and n should be positive!')
 
